@@ -1,17 +1,14 @@
-from Acquisition import aq_parent
 from collections import deque
 from copy import deepcopy
 from plone import api
 from plone.restapi.behaviors import IBlocks
 from plone.restapi.deserializer.dxfields import DefaultFieldDeserializer
+from plone.restapi.deserializer.utils import path2uid
 from plone.restapi.interfaces import IBlockFieldDeserializationTransformer
 from plone.restapi.interfaces import IFieldDeserializer
 from plone.schema import IJSONField
-from plone.uuid.interfaces import IUUID
-from plone.uuid.interfaces import IUUIDAware
 from Products.CMFPlone.interfaces import IPloneSiteRoot
 from zope.component import adapter
-from zope.component import getMultiAdapter
 from zope.component import subscribers
 from zope.interface import implementer
 from zope.publisher.interfaces.browser import IBrowserRequest
@@ -32,42 +29,6 @@ def iterate_children(value):
             queue.extend(child["children"] or [])
 
 
-def path2uid(context, link):
-    # unrestrictedTraverse requires a string on py3. see:
-    # https://github.com/zopefoundation/Zope/issues/674
-    if not link:
-        return ""
-    portal = getMultiAdapter(
-        (context, context.REQUEST), name="plone_portal_state"
-    ).portal()
-    portal_url = portal.portal_url()
-    portal_path = "/".join(portal.getPhysicalPath())
-    path = link
-    context_url = context.absolute_url()
-    relative_up = len(context_url.split("/")) - len(portal_url.split("/"))
-    if path.startswith(portal_url):
-        path = path[len(portal_url) + 1 :]
-    if not path.startswith(portal_path):
-        path = "{portal_path}/{path}".format(
-            portal_path=portal_path, path=path.lstrip("/")
-        )
-    obj = portal.unrestrictedTraverse(path, None)
-    if obj is None or obj == portal:
-        return link
-    segments = path.split("/")
-    suffix = ""
-    while not IUUIDAware.providedBy(obj):
-        obj = aq_parent(obj)
-        suffix += "/" + segments.pop()
-    # check if obj is wrong because of acquisition
-    if "/".join(obj.getPhysicalPath()) != "/".join(segments):
-        return link
-    href = relative_up * "../" + "resolveuid/" + IUUID(obj)
-    if suffix:
-        href += suffix
-    return href
-
-
 @implementer(IFieldDeserializer)
 @adapter(IJSONField, IBlocks, IBrowserRequest)
 class BlocksJSONFieldDeserializer(DefaultFieldDeserializer):
@@ -136,6 +97,7 @@ class ResolveUIDDeserializerBase:
 
     order = 1
     block_type = None
+    fields = ["url", "href"]
     disabled = os.environ.get("disable_transform_resolveuid", False)
 
     def __init__(self, context, request):
@@ -144,7 +106,7 @@ class ResolveUIDDeserializerBase:
 
     def __call__(self, block):
         # Convert absolute links to resolveuid
-        for field in ["url", "href"]:
+        for field in self.fields:
             link = block.get(field, "")
             if link and isinstance(link, str):
                 block[field] = path2uid(context=self.context, link=link)
