@@ -17,7 +17,7 @@ class TypesPost(Service):
     """Creates a new field/fieldset"""
 
     def __init__(self, context, request):
-        super(TypesPost, self).__init__(context, request)
+        super().__init__(context, request)
         self.params = []
 
     def publishTraverse(self, request, name):
