@@ -3,6 +3,7 @@ from datetime import datetime
 from datetime import time
 from datetime import timedelta
 from decimal import Decimal
+from importlib import import_module
 from plone.app.textfield.value import RichTextValue
 from plone.dexterity.utils import iterSchemata
 from plone.namedfile.file import NamedBlobFile
@@ -12,10 +13,9 @@ from plone.namedfile.file import NamedImage
 from plone.restapi.interfaces import IFieldSerializer
 from plone.restapi.serializer.dxfields import DefaultFieldSerializer
 from plone.restapi.testing import PLONE_RESTAPI_DX_INTEGRATION_TESTING
-from plone.scale import storage
+from plone.restapi.tests.helpers import patch_scale_uuid
 from plone.uuid.interfaces import IUUID
 from unittest import TestCase
-from unittest.mock import patch
 from z3c.form.interfaces import IDataManager
 from zope.component import getMultiAdapter
 from zope.interface.verify import verifyClass
@@ -23,6 +23,11 @@ from zope.interface.verify import verifyClass
 import os
 
 
+HAS_PLONE_6 = getattr(
+    import_module("Products.CMFPlone.factory"), "PLONE60MARKER", False
+)
+
+
 class TestDexterityFieldSerializing(TestCase):
     layer = PLONE_RESTAPI_DX_INTEGRATION_TESTING
     maxDiff = None
@@ -381,7 +386,8 @@ class TestDexterityImageFieldSerializingOriginalAndPNGScales(TestCase):
         with open(image_file, "rb") as f:
             image_data = f.read()
         fn = "test_namedimage_field"
-        with patch.object(storage, "uuid4", return_value="uuid_1"):
+        scale_url_uuid = "uuid_1"
+        with patch_scale_uuid(scale_url_uuid):
             value = self.serialize(
                 fn,
                 NamedImage(
@@ -390,7 +396,6 @@ class TestDexterityImageFieldSerializingOriginalAndPNGScales(TestCase):
             )
             self.assertTrue(isinstance(value, dict), "Not a <dict>")
 
-            scale_url_uuid = "uuid_1"
             obj_url = self.doc1.absolute_url()
 
             # Original image is still a "scale"
@@ -431,6 +436,34 @@ class TestDexterityImageFieldSerializingOriginalAndPNGScales(TestCase):
                     "height": 576,
                 },
             }
+            if HAS_PLONE_6:
+                # PLIP #3279 amended the image scales
+                # https://github.com/plone/Products.CMFPlone/pull/3450
+                scales["great"] = {
+                    "download": scale_download_url,
+                    "height": 768,
+                    "width": 1024,
+                }
+                scales["huge"] = {
+                    "download": scale_download_url,
+                    "height": 768,
+                    "width": 1024,
+                }
+                scales["larger"] = {
+                    "download": scale_download_url,
+                    "height": 750,
+                    "width": 1000,
+                }
+                scales["large"] = {
+                    "download": scale_download_url,
+                    "height": 600,
+                    "width": 800,
+                }
+                scales["teaser"] = {
+                    "download": scale_download_url,
+                    "height": 450,
+                    "width": 600,
+                }
             self.assertEqual(
                 {
                     "filename": "1024x768.gif",
@@ -449,7 +482,8 @@ class TestDexterityImageFieldSerializingOriginalAndPNGScales(TestCase):
         is returned as is and we need to check it, but the scales should be empty"""
         image_data = b"INVALID IMAGE DATA"
         fn = "test_namedimage_field"
-        with patch.object(storage, "uuid4", return_value="uuid_1"):
+        scale_url_uuid = "uuid_1"
+        with patch_scale_uuid(scale_url_uuid):
             value = self.serialize(
                 fn,
                 NamedImage(
@@ -458,7 +492,6 @@ class TestDexterityImageFieldSerializingOriginalAndPNGScales(TestCase):
             )
 
         obj_url = self.doc1.absolute_url()
-        scale_url_uuid = "uuid_1"
         self.assertEqual(
             {
                 "content-type": "image/gif",
@@ -480,7 +513,8 @@ class TestDexterityImageFieldSerializingOriginalAndPNGScales(TestCase):
         with open(image_file, "rb") as f:
             image_data = f.read()
         fn = "test_namedblobimage_field"
-        with patch.object(storage, "uuid4", return_value="uuid_1"):
+        scale_url_uuid = "uuid_1"
+        with patch_scale_uuid(scale_url_uuid):
             value = self.serialize(
                 fn,
                 NamedBlobImage(
@@ -489,7 +523,6 @@ class TestDexterityImageFieldSerializingOriginalAndPNGScales(TestCase):
             )
             self.assertTrue(isinstance(value, dict), "Not a <dict>")
 
-            scale_url_uuid = "uuid_1"
             obj_url = self.doc1.absolute_url()
 
             # Original image is still a "scale"
@@ -530,6 +563,34 @@ class TestDexterityImageFieldSerializingOriginalAndPNGScales(TestCase):
                     "height": 576,
                 },
             }
+            if HAS_PLONE_6:
+                # PLIP #3279 amended the image scales
+                # https://github.com/plone/Products.CMFPlone/pull/3450
+                scales["great"] = {
+                    "download": scale_download_url,
+                    "height": 768,
+                    "width": 1024,
+                }
+                scales["huge"] = {
+                    "download": scale_download_url,
+                    "height": 768,
+                    "width": 1024,
+                }
+                scales["larger"] = {
+                    "download": scale_download_url,
+                    "height": 750,
+                    "width": 1000,
+                }
+                scales["large"] = {
+                    "download": scale_download_url,
+                    "height": 600,
+                    "width": 800,
+                }
+                scales["teaser"] = {
+                    "download": scale_download_url,
+                    "height": 450,
+                    "width": 600,
+                }
             self.assertEqual(
                 {
                     "filename": "1024x768.gif",
@@ -548,7 +609,8 @@ class TestDexterityImageFieldSerializingOriginalAndPNGScales(TestCase):
         is returned as is and we need to check it, but the scales should be empty"""
         image_data = b"INVALID IMAGE DATA"
         fn = "test_namedblobimage_field"
-        with patch.object(storage, "uuid4", return_value="uuid_1"):
+        scale_url_uuid = "uuid_1"
+        with patch_scale_uuid(scale_url_uuid):
             value = self.serialize(
                 fn,
                 NamedBlobImage(
@@ -557,7 +619,6 @@ class TestDexterityImageFieldSerializingOriginalAndPNGScales(TestCase):
             )
 
         obj_url = self.doc1.absolute_url()
-        scale_url_uuid = "uuid_1"
         self.assertEqual(
             {
                 "content-type": "image/gif",
