@@ -29,10 +29,10 @@ class TestJsonCompatibleConverters(TestCase):
             + r" \(<(class|type) \'object\'>\) JSON compatible.$"
         )
 
-        with self.assertRaisesRegexp(TypeError, err_regex):
+        with self.assertRaisesRegex(TypeError, err_regex):
             json_compatible(object())
 
-        with self.assertRaisesRegexp(TypeError, err_regex):
+        with self.assertRaisesRegex(TypeError, err_regex):
             json_compatible({"foo": [object()]})
 
     def test_True(self):
