@@ -12,6 +12,7 @@ from Products.MailHost.interfaces import IMailHost
 from zope.component import getAdapter
 from zope.component import getUtility
 
+import os
 import transaction
 import unittest
 
@@ -66,6 +67,16 @@ class TestUsersEndpoint(unittest.TestCase):
         self.api_session.close()
         self.anon_api_session.close()
 
+    def makeRealImage(self):
+        import Products.PlonePAS as ppas
+        from Products.PlonePAS.tests import dummy
+
+        pas_path = os.path.dirname(ppas.__file__)
+        path = os.path.join(pas_path, "tool.gif")
+        image = open(path, "rb")
+        image_upload = dummy.FileUpload(dummy.FieldStorage(image))
+        return image_upload
+
     def test_list_users(self):
         response = self.api_session.get("/@users")
 
@@ -330,6 +341,17 @@ class TestUsersEndpoint(unittest.TestCase):
         self.assertEqual(response.status_code, 401)
         noam_api_session.close()
 
+    def test_get_user_with_portrait_set(self):
+        image = self.makeRealImage()
+        pm = api.portal.get_tool("portal_membership")
+        pm.changeMemberPortrait(image, "noam")
+        transaction.commit()
+
+        response = self.api_session.get("/@users/noam")
+
+        self.assertEqual(response.status_code, 200)
+        self.assertTrue(response.json()["portrait"].endswith("/@portrait/noam"))
+
     def test_get_search_user_with_filter(self):
         response = self.api_session.post(
             "/@users",
@@ -482,9 +504,7 @@ class TestUsersEndpoint(unittest.TestCase):
         transaction.commit()
 
         user = self.api_session.get("/@users/noam").json()
-        self.assertTrue(
-            user.get("portrait").endswith("plone/portal_memberdata/portraits/noam")
-        )
+        self.assertTrue(user.get("portrait").endswith("/@portrait/noam"))
 
     def test_update_portrait_with_default_plone_scaling(self):
         payload = {
@@ -503,9 +523,7 @@ class TestUsersEndpoint(unittest.TestCase):
         transaction.commit()
 
         user = self.api_session.get("/@users/noam").json()
-        self.assertTrue(
-            user.get("portrait").endswith("plone/portal_memberdata/portraits/noam")
-        )
+        self.assertTrue(user.get("portrait").endswith("/@portrait/noam"))
 
     def test_update_portrait_by_manager(self):
         payload = {
@@ -522,9 +540,7 @@ class TestUsersEndpoint(unittest.TestCase):
         transaction.commit()
 
         user = self.api_session.get("/@users/noam").json()
-        self.assertTrue(
-            user.get("portrait").endswith("plone/portal_memberdata/portraits/noam")
-        )
+        self.assertTrue(user.get("portrait").endswith("/@portrait/noam"))
 
     def test_delete_portrait(self):
         payload = {
@@ -572,7 +588,7 @@ class TestUsersEndpoint(unittest.TestCase):
             "fullname": "Noam A. Chomsky",
             "username": "noam",
             "email": "avram.chomsky@plone.org",
-            "portrait": "http://localhost:55001/plone/portal_memberdata/portraits/noam",
+            "portrait": "http://localhost:55001/plone/@portrait/noam",
         }
         self.api_session.auth = ("noam", "password")
         response = self.api_session.patch("/@users/noam", json=payload)
@@ -581,9 +597,7 @@ class TestUsersEndpoint(unittest.TestCase):
         transaction.commit()
 
         user = self.api_session.get("/@users/noam").json()
-        self.assertTrue(
-            user.get("portrait").endswith("plone/portal_memberdata/portraits/noam")
-        )
+        self.assertTrue(user.get("portrait").endswith("/@portrait/noam"))
 
     def test_anonymous_user_can_not_update_existing_user(self):
         payload = {
@@ -929,3 +943,61 @@ class TestUsersEndpoint(unittest.TestCase):
 
         self.assertIn("Member", response["roles"])
         self.assertEqual(1, len(response["roles"]))
+
+    def test_get_own_user_portrait(self):
+        image = self.makeRealImage()
+        pm = api.portal.get_tool("portal_membership")
+        pm.changeMemberPortrait(image, "admin")
+        transaction.commit()
+
+        response = self.api_session.get(
+            "/@portrait",
+        )
+
+        self.assertEqual(200, response.status_code)
+        self.assertEqual(response.headers["Content-Type"], "image/gif")
+
+    def test_get_own_user_portrait_logged_out(self):
+        image = self.makeRealImage()
+        pm = api.portal.get_tool("portal_membership")
+        pm.changeMemberPortrait(image, "admin")
+        transaction.commit()
+
+        response = self.anon_api_session.get(
+            "/@portrait",
+        )
+
+        self.assertEqual(404, response.status_code)
+
+    def test_get_user_portrait_not_set(self):
+        response = self.anon_api_session.get(
+            "/@portrait/admin",
+        )
+
+        self.assertEqual(404, response.status_code)
+
+    def test_get_user_portrait(self):
+        image = self.makeRealImage()
+        pm = api.portal.get_tool("portal_membership")
+        pm.changeMemberPortrait(image, "admin")
+        transaction.commit()
+
+        response = self.api_session.get(
+            "/@portrait/admin",
+        )
+
+        self.assertEqual(200, response.status_code)
+        self.assertEqual(response.headers["Content-Type"], "image/gif")
+
+    def test_get_user_portrait_anonymous(self):
+        image = self.makeRealImage()
+        pm = api.portal.get_tool("portal_membership")
+        pm.changeMemberPortrait(image, "admin")
+        transaction.commit()
+
+        response = self.anon_api_session.get(
+            "/@portrait/admin",
+        )
+
+        self.assertEqual(200, response.status_code)
+        self.assertEqual(response.headers["Content-Type"], "image/gif")
