@@ -28,7 +28,7 @@ def rename_tiles_to_blocks(setup_context):
             ]
             new_fti.append(SHORT_NEW_NAME)
             fti.behaviors = tuple(new_fti)
-            logger.info("Migrated behavior of {} type".format(_type))
+            logger.info(f"Migrated behavior of {_type} type")
 
         # In case we used the short behavior name
         if fti and SHORT_OLD_BEHAVIOR_NAME in fti.behaviors:
@@ -40,10 +40,10 @@ def rename_tiles_to_blocks(setup_context):
             ]
             new_fti.append(SHORT_NEW_NAME)
             fti.behaviors = tuple(new_fti)
-            logger.info("Migrated behavior of {} type".format(_type))
+            logger.info(f"Migrated behavior of {_type} type")
 
     for brain in api.content.find(portal_type=types_with_tiles_behavior):
         obj = brain.getObject()
         obj.blocks = getattr(obj, "tiles", {})
         obj.blocks_layout = getattr(obj, "tiles_layout", {"items": []})
-        logger.info("Migrated fields of content object: {}".format(obj.absolute_url()))
+        logger.info(f"Migrated fields of content object: {obj.absolute_url()}")
